@@ -2,12 +2,12 @@ package Clustericious::Command::configure;
 
 use strict;
 use warnings;
-use 5.010;
+use v5.10;
 use Mojo::Base 'Clustericious::Command';
 use Path::Class qw/dir/;
 
 # ABSTRACT: Generate a default configuration.
-our $VERSION = '0.9940_04'; # VERSION
+our $VERSION = '0.9930'; # VERSION
 
 
 has description => <<EOT;
@@ -59,7 +59,7 @@ Clustericious::Command::configure - Generate a default configuration.
 
 =head1 VERSION
 
-version 0.9940_04
+version 0.9930
 
 =head1 SYNOPSIS
 
