@@ -1,9 +1,31 @@
 package Clustericious::Command::generate;
 
+use strict;
+use warnings;
+use Mojo::Base 'Mojolicious::Command::generate';
+
+# ABSTRACT: Clustericious code generation commands.
+our $VERSION = '0.9930'; # VERSION
+
+
+has namespaces =>
+      sub { [qw/Clustericious::Command::generate
+                Mojolicious::Command::generate
+                Mojo::Command::generate/] };
+
+1;
+
+__END__
+=pod
+
 =head1 NAME
 
 Clustericious::Command::generate - Clustericious code generation commands.
 
+=head1 VERSION
+
+version 0.9930
+
 =head1 SYNOPSIS
 
  % clustericious generate mbd_app Myapp --schema schema.sql
@@ -22,18 +44,22 @@ L<Mojolicious::Command::generate>
 
 L<Clustericious>
 
+=head1 AUTHOR
+
+original author: Brian Duggan
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Curt Tilmes
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-use strict;
-use warnings;
-
-use Mojo::Base 'Mojolicious::Command::generate';
-
-our $VERSION = '0.9929';
-
-has namespaces =>
-      sub { [qw/Clustericious::Command::generate
-                Mojolicious::Command::generate
-                Mojo::Command::generate/] };
-
-1;
