@@ -2,38 +2,16 @@ package Clustericious::Command::generate::mbd_app;
 
 use strict;
 use warnings;
-
 use Mojo::Base 'Clustericious::Command';
-
 use File::Find;
 use File::Slurp 'slurp';
 use File::ShareDir 'dist_dir';
 use File::Basename qw/basename/;
 
-=head1 NAME
-
-Clustericious::Command::generate::mbd_app - Clustericious command to generate a new Clustericious M::B::D application
-
-=head1 SYNOPSIS
-
- % clustericious generate mbd_app Myapp --schema schema.sql
-
-=head1 DESCRIPTION
-
-This command generates a new Clustericious Module::Build::Database application with the given name and schema.
-
-=head1 SUPER CLASS
-
-L<Clustericious::Command>
-
-=head1 SEE ALSO
-
-L<Clustericious>
-
-=cut
+# ABSTRACT: Clustericious command to generate a new Clustericious M::B::D application
+our $VERSION = '0.9930'; # VERSION
 
 
-our $VERSION = '0.9929';
 
 has description => <<'EOF';
 Generate Clustericious app based on Module::Build::Database.
@@ -43,13 +21,6 @@ has usage => <<"EOF";
 usage: $0 generate mbd_app [NAME]
 EOF
 
-sub get_data
-{
-    my ($self, $data, $class) = @_;
-
-    return slurp($data);
-}
-
 sub _installfile
 {
     my $self = shift;
@@ -92,3 +63,50 @@ sub run
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Clustericious::Command::generate::mbd_app - Clustericious command to generate a new Clustericious M::B::D application
+
+=head1 VERSION
+
+version 0.9930
+
+=head1 SYNOPSIS
+
+ % clustericious generate mbd_app Myapp --schema schema.sql
+
+=head1 DESCRIPTION
+
+This command generates a new Clustericious Module::Build::Database application with the given name and schema.
+
+=head1 SUPER CLASS
+
+L<Clustericious::Command>
+
+=head1 SEE ALSO
+
+L<Clustericious>
+
+=head1 AUTHOR
+
+original author: Brian Duggan
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Curt Tilmes
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
