@@ -1,38 +1,17 @@
-=head1 NAME
-
-Clustericious::Command::status - Clustericious command to report status of Clustericious application
-
-=head1 SYNOPSIS
-
- % yourapp status
-
-=head1 DESCRIPTION
-
-Report the status of a running clustericious daemon, based on its start_mode.
-
-=head1 SUPER CLASS
-
-L<Clustericious::Command>
-
-=head1 SEE ALSO
-
-L<Clustericious>
-
-=cut
-
 package Clustericious::Command::status;
+
+use strict;
+use warnings;
 use Clustericious::Log;
 use Mojo::UserAgent;
-
 use Clustericious::App;
 use Clustericious::Config;
 use File::Basename qw/dirname/;
 use base 'Clustericious::Command';
 
-use strict;
-use warnings;
+# ABSTRACT: Clustericious command to report status of Clustericious application
+our $VERSION = '0.9930'; # VERSION
 
-our $VERSION = '0.9929';
 
 __PACKAGE__->attr(description => <<'');
 Report the status of a daemon.
@@ -124,3 +103,50 @@ sub run {
 
 1;
 
+
+__END__
+=pod
+
+=head1 NAME
+
+Clustericious::Command::status - Clustericious command to report status of Clustericious application
+
+=head1 VERSION
+
+version 0.9930
+
+=head1 SYNOPSIS
+
+ % yourapp status
+
+=head1 DESCRIPTION
+
+Report the status of a running clustericious daemon, based on its start_mode.
+
+=head1 SUPER CLASS
+
+L<Clustericious::Command>
+
+=head1 SEE ALSO
+
+L<Clustericious>
+
+=head1 AUTHOR
+
+original author: Brian Duggan
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Curt Tilmes
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
