@@ -1,39 +1,14 @@
 package Clustericious::Controller;
-use Clustericious::Config;
-use Clustericious::Log;
-
-use base 'Mojolicious::Controller';
 
 use strict;
 use warnings;
+use Clustericious::Config;
+use Clustericious::Log;
+use base 'Mojolicious::Controller';
 
-=head1 NAME
+# ABSTRACT: Clustericious controller base class
+our $VERSION = '0.9930'; # VERSION
 
-Clustericious::Controller - Clustericious controller base class
-
-=head1 SYNOPSIS
-
- use base qw( Clustericious::Controller );
-
-=head1 DESCRIPTION
-
-Base class for all controllers in Clustericious applications
-
-=head1 SUPER CLASS
-
-L<Mojolicious::Controller>
-
-=cut
-
-our $VERSION = '0.9929';
-
-=head1 METHODS
-
-=head2 $c-E<gt>url_for
-
-Clustericious version of this method usually provided by Mojolicious.
-
-=cut
 
 sub url_for {
     my $c = shift;
@@ -49,18 +24,6 @@ sub url_for {
     return $url;
 }
 
-=head2 redirect_to
-
-Copied from Mojolicious::Controller, but works around
-a limitation of apache's mod_proxy (namely: the ProxyPassReverse
-directive doesn't handle authorization information in the
-Location header.)
-
-It does this by explicitly using the url_base from the
-Clustericious config file for the app as the base for
-the location header.
-
-=cut
 
 sub redirect_to {
     my $self = shift;
@@ -88,11 +51,6 @@ sub redirect_to {
     return $self;
 }
 
-=head2 $c-E<gt>render_not_found
-
-Clustericious version of this method usually provided by Mojolicious.
-
-=cut
 
 sub render_not_found {
     my $self = shift;
@@ -100,19 +58,6 @@ sub render_not_found {
     $self->SUPER::render_not_found(@_);
 }
 
-=head2 $c-E<gt>render_text
-
-Only provided when Mojolicious < 4.0.  Previous versions of Mojolicious included this
-method, and it was added here to ease the transition.  This method should be considered
-deprecated and may be removed in the future.
-
-=head2 $c-E<gt>render_json
-
-Only provided when Mojolicious < 4.0.  Previous versions of Mojolicious included this
-method, and it was added here to ease the transition.  This method should be considered
-deprecated and may be removed in the future.
-
-=cut
 
 if($Mojolicious::VERSION >= 4.0)
 {
@@ -126,8 +71,83 @@ if($Mojolicious::VERSION >= 4.0)
 
 1;
 
+
+__END__
+=pod
+
+=head1 NAME
+
+Clustericious::Controller - Clustericious controller base class
+
+=head1 VERSION
+
+version 0.9930
+
+=head1 SYNOPSIS
+
+ use base qw( Clustericious::Controller );
+
+=head1 DESCRIPTION
+
+Base class for all controllers in Clustericious applications
+
+=head1 SUPER CLASS
+
+L<Mojolicious::Controller>
+
+=head1 METHODS
+
+=head2 $c-E<gt>url_for
+
+Clustericious version of this method usually provided by Mojolicious.
+
+=head2 redirect_to
+
+Copied from Mojolicious::Controller, but works around
+a limitation of Apache's mod_proxy (namely: the ProxyPassReverse
+directive doesn't handle authorization information in the
+Location header.)
+
+It does this by explicitly using the url_base from the
+Clustericious config file for the app as the base for
+the location header.
+
+=head2 $c-E<gt>render_not_found
+
+Clustericious version of this method usually provided by Mojolicious.
+
+=head2 $c-E<gt>render_text
+
+Only provided when Mojolicious < 4.0.  Previous versions of Mojolicious included this
+method, and it was added here to ease the transition.  This method should be considered
+deprecated and may be removed in the future.
+
+=head2 $c-E<gt>render_json
+
+Only provided when Mojolicious < 4.0.  Previous versions of Mojolicious included this
+method, and it was added here to ease the transition.  This method should be considered
+deprecated and may be removed in the future.
+
 =head1 SEE ALSO
 
 L<Clustericious>
 
-=cut
\ No newline at end of file
+=head1 AUTHOR
+
+original author: Brian Duggan
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Curt Tilmes
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
