@@ -1,50 +1,14 @@
 package Clustericious::RouteBuilder::CRUD;
 
-=head1 NAME
-
-Clustericious::RouteBuilder::CRUD - build crud routes easily
-
-=head1 SYNOPSIS
-
-    use My::Object::Class;
-    use Clustericious::RouteBuilder;
-    use Clustericious::RouteBuilder::CRUD
-            "create" => { -as => "do_create" },
-            "read"   => { -as => "do_read"   },
-            "delete" => { -as => "do_delete" },
-            "update" => { -as => "do_update" },
-            "list"   => { -as => "do_list"   },
-            defaults => { finder => "My::Finder::Class" },
-        ;
-
-    ...
-
-    post => "/:table" => \&do_create;
-
-=head1 DESCRIPTION
-
-This package provides some handy subroutines for building CRUD
-routes in your clustericious application.
-
-The class referenced by "finder" must have methods named
-find_class and find_object.
-
-The objects returned by find_object must have a method named as_hash.
-
-=head1 SUPER CLASS
-
-none
-
-=head1 SEE ALSO
-
-L<Clustericious>
-
-=cut
-
 use strict;
+use warnings;
 use Clustericious::Log;
 use Data::Dumper;
 
+# ABSTRACT: build crud routes easily
+our $VERSION = '0.9930'; # VERSION 
+
+
 use Sub::Exporter -setup => {
     exports => [
         "create" => \&_build_create,
@@ -56,8 +20,6 @@ use Sub::Exporter -setup => {
     collectors => ['defaults'],
 };
 
-our $VERSION = '0.9929';
-
 sub _build_create {
     my ($class, $name, $arg, $defaults) = @_;
     my $finder = $arg->{finder} || $defaults->{defaults}{finder} || die "no finder defined";
@@ -216,3 +178,69 @@ sub _build_list {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Clustericious::RouteBuilder::CRUD - build crud routes easily
+
+=head1 VERSION
+
+version 0.9930
+
+=head1 SYNOPSIS
+
+    use My::Object::Class;
+    use Clustericious::RouteBuilder;
+    use Clustericious::RouteBuilder::CRUD
+            "create" => { -as => "do_create" },
+            "read"   => { -as => "do_read"   },
+            "delete" => { -as => "do_delete" },
+            "update" => { -as => "do_update" },
+            "list"   => { -as => "do_list"   },
+            defaults => { finder => "My::Finder::Class" },
+        ;
+
+    ...
+
+    post => "/:table" => \&do_create;
+
+=head1 DESCRIPTION
+
+This package provides some handy subroutines for building CRUD
+routes in your clustericious application.
+
+The class referenced by "finder" must have methods named
+find_class and find_object.
+
+The objects returned by find_object must have a method named as_hash.
+
+=head1 SUPER CLASS
+
+none
+
+=head1 SEE ALSO
+
+L<Clustericious>
+
+=head1 AUTHOR
+
+original author: Brian Duggan
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Curt Tilmes
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
