@@ -1,50 +1,19 @@
-=head1 NAME
-
-Clustericious::RouteBuilder::Common - Routes common to all clustericious apps.
-
-=head1 SYNOPSIS
-
- Clustericious::RouteBuilder::Common->add_routes($app);
-
-=head1 DESCRIPTION
-
-This package adds routes that are common to all clustericious servers.
-
-These routes will be added first; they cannot be overridden.  The following
-routes are added :
-
-    GET /version
-    GET /status
-    GET /api
-    GET /log
-    OPTIONS /
-
-/log is not available unless the configuration option "export_logs" is set
-to a true value.
-
-=head1 SUPER CLASS
-
-none
-
-=head1 SEE ALSO
-
-L<Clustericious>
-
-=cut
-
 package Clustericious::RouteBuilder::Common;
-use Clustericious::Log;
-use Sys::Hostname qw/hostname/;
-
-our $VERSION = '0.9929';
 
 use strict;
 use warnings;
+use Clustericious::Log;
+use Sys::Hostname qw/hostname/;
 
-sub add_routes {
+# ABSTRACT: Routes common to all clustericious apps.
+our $VERSION = '0.9930'; # VERSION
+
+
+sub _add_routes {
     my $class = shift;
     my $app = shift;
 
+
     $app->routes->route('/version')->to(
         cb => sub {
             my $self = shift;
@@ -52,6 +21,7 @@ sub add_routes {
         }
     );
 
+
     $app->routes->route('/status')->to(
         cb => sub {
             my $self = shift;
@@ -63,6 +33,7 @@ sub add_routes {
         }
     );
 
+
     $app->routes->route('/api')->to(
         cb => sub {
             my $self = shift;
@@ -70,6 +41,7 @@ sub add_routes {
             }
     );
 
+
     $app->routes->route('/api/:table')->to(
         cb => sub {
             my($self) = @_;
@@ -77,6 +49,7 @@ sub add_routes {
             $table ? $self->render( autodata => $table ) : $self->render_not_found;
         },
     );
+    
 
     $app->routes->get('/log/:lines' => [ lines => qr/\d+/ ] =>
         sub {
@@ -99,3 +72,98 @@ sub add_routes {
 
 1;
 
+
+__END__
+=pod
+
+=head1 NAME
+
+Clustericious::RouteBuilder::Common - Routes common to all clustericious apps.
+
+=head1 VERSION
+
+version 0.9930
+
+=head1 DESCRIPTION
+
+This package adds routes that are common to all clustericious servers.
+
+=head1 SUPER CLASS
+
+none
+
+=head2 /version
+
+Returns the version of the service as a single element list.
+
+=head2 /status
+
+Returns status information about the service.  This comes back
+as a hash that includes these key/value pairs:
+
+=over 4
+
+=item app_name
+
+The name of the application (example: "MyApp")
+
+=item server_hostname
+
+The server on which the service is running.
+
+=item server_url
+
+The URL to use for the service.
+
+=item server_version
+
+The version of the application.
+
+=back
+
+=head2 /api
+
+Returns a list of API routes for the service.  This is similar to the information
+provided by the L<Mojolicious::Command::routes|routes command>.
+
+=head2 /api/:table
+
+If you are using L<Module::Build::Database> and L<Route::Planter> for a database
+back end to your L<Clustericious> application you can get the columns of each
+table using this route.
+
+=head2 /log/:lines
+
+Return the last several lines from the application log (number specified by :lines
+and defaults to 10 if not specified).
+
+Only available if you set export_logs to true in your application's server configuration.
+
+example C<~/etc/MyApp.conf>:
+
+ ---
+ export_logs: 1
+
+=head1 SEE ALSO
+
+L<Clustericious>, L<Clustericious::RouteBuilder>
+
+=head1 AUTHOR
+
+original author: Brian Duggan
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Curt Tilmes
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
