@@ -1,51 +1,12 @@
 package Clustericious::RouteBuilder::Proxy;
 
-=head1 NAME
-
-Clustericious::RouteBuilder::Proxy - build proxy routes easily
-
-=head1 SYNOPSIS
-
-    use My::Object::Class;
-    use Clustericious::RouteBuilder;
-    use Clustericious::RouteBuilder::Proxy
-      "proxy" => {
-        to            => "http://google.com:80",
-        strip_prefix  => "/google",
-        -as           => "proxy_google",
-      },
-      "proxy" => {
-        app => 'MyServer',
-        -as => "proxy_local"
-      },
-      proxy_service => {  # Bulk mapping
-             services => { "froogle" => "http://froogle.com",
-                           "fraggle" => "http://fraggle.com" }
-      };
-
-    ...
-    get '/google/:somewhere'    => \&proxy_google;
-    get '/something/:somewhere' => \&proxy_local;
-    get '/:service/(*whatever)' => \&proxy_service;
-
-=head1 DESCRIPTION
-
-This package provides routes for proxying.  It rewrites
-urls by stripping prefixes, and passes the rest on by
-prepending a given url to the incoming request.
-
-=head1 SUPER CLASS
-
-none
-
-=head1 SEE ALSO
-
-L<Clustericious>
-
-=cut
-
-use Clustericious::Log;
 use strict;
+use warnings;
+use Clustericious::Log;
+
+# ABSTRACT: build proxy routes easily
+our $VERSION = '0.9930'; # VERSION
+
 
 use Sub::Exporter -setup => {
     exports => [
@@ -55,8 +16,6 @@ use Sub::Exporter -setup => {
     collectors => ['defaults'],
 };
 
-our $VERSION = '0.9929';
-
 sub _build_proxy {
     my ( $class, $name, $arg, $defaults ) = @_;
     my $strip_prefix  = $arg->{strip_prefix};
@@ -147,3 +106,72 @@ sub _sanitize_url {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Clustericious::RouteBuilder::Proxy - build proxy routes easily
+
+=head1 VERSION
+
+version 0.9930
+
+=head1 SYNOPSIS
+
+    use My::Object::Class;
+    use Clustericious::RouteBuilder;
+    use Clustericious::RouteBuilder::Proxy
+      "proxy" => {
+        to            => "http://google.com:80",
+        strip_prefix  => "/google",
+        -as           => "proxy_google",
+      },
+      "proxy" => {
+        app => 'MyServer',
+        -as => "proxy_local"
+      },
+      proxy_service => {  # Bulk mapping
+             services => { "froogle" => "http://froogle.com",
+                           "fraggle" => "http://fraggle.com" }
+      };
+
+    ...
+    get '/google/:somewhere'    => \&proxy_google;
+    get '/something/:somewhere' => \&proxy_local;
+    get '/:service/(*whatever)' => \&proxy_service;
+
+=head1 DESCRIPTION
+
+This package provides routes for proxying.  It rewrites
+URLs by stripping prefixes, and passes the rest on by
+prepending a given url to the incoming request.
+
+=head1 SUPER CLASS
+
+none
+
+=head1 SEE ALSO
+
+L<Clustericious>
+
+=head1 AUTHOR
+
+original author: Brian Duggan
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Curt Tilmes
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
