@@ -1,60 +1,15 @@
-=head1 NAME
-
-Clustericious::RouteBuilder::Search - build routes for searching for objects
-
-=head1 SYNOPSIS
-
-    use My::Object::Class;
-    use Clustericious::RouteBuilder;
-    use Clustericious::RouteBuilder::Search
-            "search",
-            "plurals",
-            defaults => { manager_finder => "Manager::Finder::Class" },
-        ;
-
-    ...
-
-    post => "/:plural/search" => [ plural => [ plurals() ] ] => \&do_create;
-
-=head1 DESCRIPTION
-
-This automates the creation of routes for searching for objects.
-
-Manager::Finder::Class must provide the following methods :
-
-=over 4
-
-=item lookup_class
-
-given the plural of a table, look up the name of the class
-
-=back
-
-The route that is created turns a JSON structure which is POSTed into
-parameters for Rose::DB::Object::Manager::get_objects.
-
-Additionally a "mode" parameters is suported, which just calls a
-search_$mode method within the manager class, and returns that
-resultset to the client.
-
-=head1 SUPER CLASS
-
-none
-
-=head1 SEE ALSO
-
-L<Clustericious>
-
-=cut
-
 package Clustericious::RouteBuilder::Search;
+
+use strict;
+use warnings;
 use Mojo::JSON;
 use Clustericious::Log;
 use List::MoreUtils qw/uniq/;
 use Data::Dumper;
-use strict;
 
-our $VERSION = '0.9929';
+# ABSTRACT: build routes for searching for objects
+our $VERSION = '0.9930'; # VERSION
+
 
 use Sub::Exporter -setup => {
     exports => [
@@ -127,3 +82,77 @@ sub _build_search {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Clustericious::RouteBuilder::Search - build routes for searching for objects
+
+=head1 VERSION
+
+version 0.9930
+
+=head1 SYNOPSIS
+
+    use My::Object::Class;
+    use Clustericious::RouteBuilder;
+    use Clustericious::RouteBuilder::Search
+            "search",
+            "plurals",
+            defaults => { manager_finder => "Manager::Finder::Class" },
+        ;
+
+    ...
+
+    post => "/:plural/search" => [ plural => [ plurals() ] ] => \&do_create;
+
+=head1 DESCRIPTION
+
+This automates the creation of routes for searching for objects.
+
+Manager::Finder::Class must provide the following methods :
+
+=over 4
+
+=item lookup_class
+
+given the plural of a table, look up the name of the class
+
+=back
+
+The route that is created turns a JSON structure which is input as POST
+data into parameters for Rose::DB::Object::Manager::get_objects.
+
+Additionally a "mode" parameters is supported, which just calls a
+search_$mode method within the manager class, and returns that
+result set to the client.
+
+=head1 SUPER CLASS
+
+none
+
+=head1 SEE ALSO
+
+L<Clustericious>
+
+=head1 AUTHOR
+
+original author: Brian Duggan
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Curt Tilmes
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
