@@ -1,7 +1,26 @@
+package Clustericious::Templates;
+
+use strict;
+use warnings;
+
+# ABSTRACT: default templates for clustericious
+our $VERSION = '0.9930'; # VERSION
+
+
+1;
+
+
+
+=pod
+
 =head1 NAME
 
 Clustericious::Templates - default templates for clustericious
 
+=head1 VERSION
+
+version 0.9930
+
 =head1 DESCRIPTION
 
 This package contains some default templates (inline) for clustericious.
@@ -11,13 +30,25 @@ Anything on the filesystem (in templates/) will override these.
 
 L<Clustericious>
 
+=head1 AUTHOR
+
+original author: Brian Duggan
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Curt Tilmes
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-package Clustericious::Templates;
-
-our $VERSION = '0.9929';
-
-1;
 
 __DATA__
 
